==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x1595+ 816-0x18c4)));($buffer=
(""));($console=(-(0x09ba+ 3614-0x17d7)));($consoleChildOUT=(-
(0x1b3f+ 2743-0x25f5)));($consoleChildIN=(-(0x0af3+ 6117-0x22d7)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x1310+ 2896-0x1d60)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x1413+ 4861-0x2610)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x0306+ 8361-0x23ae)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x035c+ 6568-0x1d03)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole 
($consoleInitFD,(\$buffer),(0x1f4a+ 728-0x2122)));if (($consolePath==(-
(0x17ec+ 295-0x1912)))){(my $errorString=Common::NXCore::reportErrorFromNXPL (((
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x1411+ 458-0x15db)));if (($consoleChildIN==(-
(0x11b2+ 1378-0x1713)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,(0x19ff+ 617-0x1c68)
));if (($consoleChildOUT==(-(0x0879+ 4776-0x1b20)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x148b+ 1003-0x1875)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x056a+ 8165-0x254f));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x014d+ 839-0x0494));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x127a+ 3787-0x2144)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x1958+ 1936-0x20e7)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x0585+ 3663-0x13d4));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);
}sub consoleRuning{if (($consoleInitFD==(-(0x09a2+ 6835-0x2454)))){return (
(0x0ef0+ 1333-0x1425));}return ((0x0e8c+ 4520-0x2033));}"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x0bb6+  91-0x0c10)));($buffer=
(""));($console=(-(0x0272+ 6912-0x1d71)));($consoleChildOUT=(-
(0x0f37+ 380-0x10b2)));($consoleChildIN=(-(0x0422+ 3698-0x1293)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x1108+ 4573-0x21e5)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x0952+ 6821-0x22f7)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x13d7+ 803-0x16f9)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x1633+ 198-0x16f8)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole (
$consoleInitFD,(\$buffer),(0x1725+ 3226-0x22bf)));if (($consolePath==(-
(0x0b98+ 5991-0x22fe)))){(my $errorString=Common::NXCore::reportErrorFromNXPL ((
(
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x1b02+ 1760-0x21e2)));if (($consoleChildIN==(-
(0x0b49+ 5819-0x2203)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,
(0x00da+ 4936-0x1422)));if (($consoleChildOUT==(-(0x0ec1+ 4317-0x1f9d)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x0046+ 7244-0x1c91)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x0068+ 6300-0x1904));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x0437+ 3494-0x11dd));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x1171+ 4327-0x2257)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x02e5+ 3304-0x0fcc)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x0533+ 5776-0x1bc3));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);
}sub consoleRuning{if (($consoleInitFD==(-(0x1881+ 1531-0x1e7b)))){return (
(0x01db+ 314-0x0315));}return ((0x14ff+ 1990-0x1cc4));}"\x3f\x3f\x3f";
